@@ -1,5 +1,11 @@
 """
-sets up sparse integration over a Gaussian
+Sets up sparse integration over a Gaussian, given text files that contain rescaled Gauss-Hermite nodes and weights.
+
+These files must be named `GHsparseGrid{ndims}prec{iprec}.txt`, where `ndims` is the number of dimensions of integration 
+and `iprec` is a precision level that must be 9, 13, or (most precise) 17. The file must have `(ndims+1) columns, 
+with the weights in the first column.
+
+The nodes and weights are rescaled so that `f(nodes) @ weights` approximates `Ef(X)` for `X` an `N(0,I)` variable.
 """
 from pathlib import Path
 
@@ -15,15 +21,16 @@ def setup_sparse_gaussian(
     """
     get nodes and weights for sparse integration Ef(X) with X = N(0,1) in `ndims` dimensions
 
-    usage: nodes, weights = setup_sparse_gaussian(mdims, iprec); intf = f(nodes) @ weights
+    usage: nodes, weights = setup_sparse_gaussian(mdims, iprec); integral_f = f(nodes) @ weights
 
     Args:
         ndims: number of dimensions (1 to 5)
         iprec: precision (must be 9, 13, or 17)
+        GHsparsedir: the name of a directory that contains nodes and weights
 
     Returns:
         a pair of  arrays `nodes` and `weights`;
-        `nodes` has `ndims`-1 columns and weights is a vector
+        `nodes` has `ndims`-1 columns and `weights` is a vector
     """
     GHdir = (
         Path.home() / "Dropbox" / "GHsparseGrids"
@@ -36,11 +43,20 @@ def setup_sparse_gaussian(
         )
 
     if ndims in [1, 2, 3, 4, 5]:
+        if not GHdir.exists():
+            bs_error_abort("I did not find the directory with the nodes/weights files.")
         grid = np.loadtxt(GHdir / f"GHsparseGrid{ndims}prec{iprec}.txt")
-        weights = grid[:, 0]
-        nodes = grid[:, 1:]
+
+        print(f"{grid.shape=}")
+        if ndims == 1:
+            weights = grid[:, 0]
+            nodes = grid[:, 1]
+        else:
+            weights = grid[:, 0]
+            nodes = grid[:, 1:]
         return nodes, weights
     else:
         bs_error_abort(
             f"We only do sparse integration in one to five dimensions, not {ndims}"
         )
+        return np.zeros(1), np.zeros(1)  # for mypy
